/*
 * term.h
 *
 * Copyright 2004, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#ifndef term_h
#define term_h


#include<proc.h>
#include<share/stropts.h>
#include<share/termios.h>


#ifndef ASM_FILE


enum{
	/* ioctl()ѥޥɡ */
	TERM_CTLCM_GETATTR=0,
	TERM_CTLCM_SETATTR,
};


typedef struct{
	PROC *ctlProc;	/* üץ */
	gid_t foregrnd;	/* ե饦ɥץ롼ס */
}TERM_CTL;


extern int isForegrouond(PROC*);
extern int isCtlproc(PROC*);


#endif


#endif
